package com.titan.travelagent;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;

import com.titan.cabin.CabinLocal;
import com.titan.cabin.CabinLocalHome;
import com.titan.ship.ShipLocal;
import com.titan.ship.ShipLocalHome;

/**
 * Bean implementation class for Enterprise Bean: TravelAgent
 */
public class TravelAgentBean implements javax.ejb.SessionBean {
	private javax.ejb.SessionContext mySessionCtx;

	javax.naming.Context ic = null;
	javax.jms.QueueConnectionFactory qConnFactory = null;
	javax.jms.QueueConnection qConn = null;
	javax.jms.Queue queue = null;
	javax.jms.QueueSession qSession = null;
	javax.jms.QueueSender qSender = null;
	javax.jms.MapMessage message = null;
	String fName = "jms/ReservationQueueFactory";
	String qName = "jms/ReservationQueue";

	/**
	 * getSessionContext
	 */
	public javax.ejb.SessionContext getSessionContext() {
		return mySessionCtx;
	}
	/**
	 * setSessionContext
	 */
	public void setSessionContext(javax.ejb.SessionContext ctx) {
		mySessionCtx = ctx;
	}
	/**
	 * ejbCreate
	 */
	public void ejbCreate() throws javax.ejb.CreateException {
	}
	/**
	 * ejbActivate
	 */
	public void ejbActivate() {
	}
	/**
	 * ejbPassivate
	 */
	public void ejbPassivate() {
	}
	/**
	 * ejbRemove
	 */
	public void ejbRemove() {
	}

	public void sendReservation() {
		try {
			ic = new javax.naming.InitialContext();
			qConnFactory = (javax.jms.QueueConnectionFactory) ic.lookup(fName);
			queue = (javax.jms.Queue) ic.lookup(qName);
		} catch (Exception e) {
			System.err.println("TravelAgentBean: JNDI lookup failed " + e);
		}

		try {
			qConn = qConnFactory.createQueueConnection();
			qSession = qConn.createQueueSession(false, javax.jms.Session.AUTO_ACKNOWLEDGE);
			qSender = qSession.createSender(queue);
			message = qSession.createMapMessage();
			message.setString("name", "Mikalai Zaikin");
			message.setString("cruise", "Hawaii");
			qSender.send(message);
			qConn.close();
			System.out.println("TravelAgentBean: Cruise reservation sent");
		} catch (Exception e) {
			System.err.println("TravelAgentBean: Error on sending message " + e);
		}
	}

	public void createCabins() {
		CabinLocalHome home = null;
		try {
			ic = new javax.naming.InitialContext();
			home = (CabinLocalHome) ic.lookup("java:comp/env/ejb/Cabin");
		} catch (Exception e) {
			System.err.println("TravelAgentBean: JNDI lookup failed " + e);
		}

		try {
			CabinLocal cab = home.create(new Integer(1));
			cab.setName("Master Suite");
			cab.setDeckLevel(1);
			cab.setShipId(1);
			cab.setBedCount(3);

			cab = home.create(new Integer(2));
			cab.setName("Suite");
			cab.setDeckLevel(2);
			cab.setShipId(1);
			cab.setBedCount(5);

			System.out.println("TravelAgentBean: cabins created");
		} catch (CreateException ce) {
			System.err.println("TravelAgentBean: can not create cabin " + ce);
		}
	}

	public void createShips() {
		ShipLocalHome home = null;
		try {
			ic = new javax.naming.InitialContext();
			home = (ShipLocalHome) ic.lookup("java:comp/env/ejb/Ship");
		} catch (Exception e) {
			System.err.println("TravelAgentBean: JNDI lookup failed " + e);
		}

		try {
			ShipLocal ship = home.create(new Integer(1), "Nordic Prince");
			ship.setCapacity(300);
			ship.setTonnage(5000.0);

			ship = home.create(new Integer(2), "Bohemian Rhapsody");
			ship.setCapacity(400);
			ship.setTonnage(6000.0);

			System.out.println("TravelAgentBean: ships created");
		} catch (CreateException ce) {
			System.err.println("TravelAgentBean: can not create ship " + ce);
		}
	}

	public void listCabins() {
		CabinLocalHome home = null;
		try {
			ic = new javax.naming.InitialContext();
			home = (CabinLocalHome) ic.lookup("java:comp/env/ejb/Cabin");
		} catch (Exception e) {
			System.err.println("TravelAgentBean: JNDI lookup failed " + e);
		}

		try {
			for (int i = 1; i < 3; i++) {
				CabinLocal cab = home.findByPrimaryKey(new Integer(i));
				System.out.println("TravelAgentBean : Cabin # " + i);
				System.out.println(" name : " + cab.getName());
				System.out.println(" deck level : " + cab.getDeckLevel());
				System.out.println(" ship ID : " + cab.getShipId());
				System.out.println(" bed count : " + cab.getBedCount());
			}
		} catch (FinderException fe) {
			System.err.println("TravelAgentBean: can not find cabin " + fe);
		}
	}

	public void listShips() {
		ShipLocalHome home = null;
		try {
			ic = new javax.naming.InitialContext();
			home = (ShipLocalHome) ic.lookup("java:comp/env/ejb/Ship");
		} catch (Exception e) {
			System.err.println("TravelAgentBean: JNDI lookup failed " + e);
		}

		try {
			for (int i = 1; i < 3; i++) {
				ShipLocal ship = home.findByPrimaryKey(new Integer(i));
				System.out.println("TravelAgentBean : Ship # " + i);
				System.out.println(" name : " + ship.getName());
				System.out.println(" tonnage : " + ship.getTonnage());
				System.out.println(" capacity : " + ship.getCapacity());
			}
		} catch (FinderException fe) {
			System.err.println("TravelAgentBean: can not find ship " + fe);
		}
	}

	public void cleanup() {
		ShipLocalHome home = null;
		try {
			ic = new javax.naming.InitialContext();
			home = (ShipLocalHome) ic.lookup("java:comp/env/ejb/Ship");
		} catch (Exception e) {
			System.err.println("TravelAgentBean: JNDI lookup failed " + e);
		}

		try {
			for (int i = 1; i < 3; i++) {
				home.remove(new Integer(i));
			}
		} catch (RemoveException re) {
			System.err.println("TravelAgentBean: can not remove ship " + re);
		} catch (Exception e) {
			System.err.println("TravelAgentBean: exception during ship removal " + e);
		}

		System.out.println("TravelAgentBean: ships removed");

		CabinLocalHome cabHome = null;
		try {
			cabHome = (CabinLocalHome) ic.lookup("java:comp/env/ejb/Cabin");
		} catch (Exception e) {
			System.err.println("TravelAgentBean: JNDI lookup failed " + e);
		}

		try {
			for (int i = 1; i < 3; i++) {
				cabHome.remove(new Integer(i));
			}
		} catch (RemoveException re) {
			System.err.println("TravelAgentBean: can not remove cabin " + re);
		} catch (Exception e) {
			System.err.println("TravelAgentBean: exception during cabin removal " + e);
		}
		System.out.println("TravelAgentBean: cabins removed");
	}

	public void sendReservation(String firstName, String lastName, String cruise) {
		try {
			ic = new javax.naming.InitialContext();
			qConnFactory = (javax.jms.QueueConnectionFactory) ic.lookup(fName);
			queue = (javax.jms.Queue) ic.lookup(qName);
		} catch (Exception e) {
			System.err.println("TravelAgentBean: JNDI lookup failed " + e);
		}

		try {
			qConn = qConnFactory.createQueueConnection();
			qSession = qConn.createQueueSession(false, javax.jms.Session.AUTO_ACKNOWLEDGE);
			qSender = qSession.createSender(queue);
			message = qSession.createMapMessage();
			message.setString("name", firstName + " " + lastName);
			message.setString("cruise", cruise);
			qSender.send(message);
			qConn.close();
			System.out.println("TravelAgentBean: Cruise reservation sent");
		} catch (Exception e) {
			System.err.println("TravelAgentBean: Error on sending message " + e);
		}
	}
}
